==> safecheck-3.0.14.jar: filiale/xinkang/sqls/FetchUserFileByOrgChecker.sql <==
SELECT
    *
FROM
    (
        SELECT
            ui.f_userinfo_id,
            ui.f_createfile_date,
            ui.f_userinfo_code,
            ua.f_street,
            ua.f_residential_area,
            ua.f_building,
            ua.f_unit,
            ua.f_floor,
            ua.f_room,
            ua.f_address,
            ui.f_user_name,
            ui.f_user_phone,
            uf.f_meter_book_num,
            ua.f_slice_area,
            uf.f_user_type,
            uf.f_meternumber,
            uf.f_meter_brand,
            tp.f_entry_status f_last_check_state,
            { f_defect_content } AS f_last_check_result,
            ui.f_comments,
            ui.version,
            ui.f_user_state,
            ui.f_filialeid,
            tp.f_checker_name ,
            tp.f_offsite_time f_last_check_date,
            cp.rhcon
        FROM
            t_userinfo ui
            LEFT JOIN t_user_address ua ON ui.f_userinfo_id= ua.f_userinfo_id
            LEFT JOIN ( SELECT f_user_type,f_meter_book_num,f_userinfo_id,
            f_meternumber, f_meter_brand  FROM t_userfiles tu
            left join t_gasbrand gb on tu.f_gasbrand_id = gb.id
            WHERE f_table_state = '正常' ) uf ON ua.f_userinfo_id= uf.f_userinfo_id
            LEFT JOIN (
              SELECT
                *
              FROM
                ( SELECT *, ROW_NUMBER () over ( partition BY f_userinfoid ORDER BY f_upload_date  DESC ) AS lastcheck FROM ( SELECT * FROM t_check_paper with (nolock) WHERE { condition.condition2 } ) tp ) t
              WHERE
                lastcheck = 1
              ) tp ON ui.f_userinfo_id = tp.f_userinfoid
           left join (
           select f_userinfoid,count(1) rhcon from (
           select
              f_entry_status,
              f_userinfoid,
              f_filialeid,
              f_offsite_time
            from t_check_paper where f_entry_status='入户' and {condition.condition2} and {condition.condition3}
           ) tcp1
          group by f_userinfoid
) cp on cp.f_userinfoid=tp.f_userinfoid
    ) a
WHERE
    { condition.condition1 }
ORDER BY
    { orderitem}

==> safecheck-3.0.72.jar: filiale/xinkang/sqls/FetchUserFileByOrgChecker.sql <==
SELECT
    *
FROM
    (
        SELECT
            ui.f_userinfo_id,
            ui.f_createfile_date,
            ui.f_userinfo_code,
            ua.f_street,
            ua.f_residential_area,
            ua.f_building,
            ua.f_unit,
            ua.f_floor,
            ua.f_room,
            ua.f_address,
            ui.f_user_name,
            ui.f_user_phone,
            uf.f_meter_book_num,
            ua.f_slice_area,
            uf.f_user_type,
            uf.f_meternumber,
            uf.f_meter_brand,
            tp.f_entry_status f_last_check_state,
            { f_defect_content } AS f_last_check_result,
            f_defect_content,
            ui.f_comments,
            ui.version,
            ui.f_user_state,
            ui.f_filialeid,
            tp.f_checker_name ,
            tp.f_offsite_time f_last_check_date,
            isnull(cp.rhcon,0) rhcon
        FROM
            t_userinfo ui
            LEFT JOIN t_user_address ua ON ui.f_userinfo_id= ua.f_userinfo_id
            LEFT JOIN ( SELECT f_user_type,f_meter_book_num,f_userinfo_id,
            f_meternumber, f_meter_brand  FROM t_userfiles tu
            left join t_gasbrand gb on tu.f_gasbrand_id = gb.id
            WHERE (f_table_state = '正常' or f_table_state = '停用') ) uf ON ua.f_userinfo_id= uf.f_userinfo_id
            LEFT JOIN (
              SELECT
                *
              FROM
                ( SELECT *, ROW_NUMBER () over ( partition BY f_userinfoid ORDER BY f_upload_date  DESC ) AS lastcheck FROM ( SELECT * FROM t_check_paper with (nolock) WHERE { condition.condition2 } ) tp ) t
              WHERE
                lastcheck = 1
              ) tp ON ui.f_userinfo_id = tp.f_userinfoid
            join (
           select f_userinfoid,sum(ruhu) rhcon from (
           select
            case when f_entry_status = '入户' then 1 else 0 end ruhu,
              f_userinfoid,
              f_filialeid,
              f_offsite_time
            from t_check_paper where  {condition.condition2} and {condition.condition3}
           ) tcp1
          group by f_userinfoid
        ) cp on cp.f_userinfoid=tp.f_userinfoid
    ) a
WHERE
    { condition.condition1 }
ORDER BY
    { orderitem}
